@@ -15,8 +15,8 @@ class ESDocument(BaseModel):
     modified: Optional[str] = datetime.now().isoformat()
     issued: Optional[str] = datetime.now().isoformat()
     periodicity: Optional[str] = ""
-    provenance: Optional[str] = ""
-    contactpoint: Optional[str] = ""
+    provenance: Optional[str] = "NAV"
+    contactpoint: Optional[dict] = ""
     author: Optional[str] = ""
     repo: Optional[str] = ""
     readme: Optional[str] = ""
